/******************************************
 *
 * $GAMGI/src/global/gamgi_global_start.h
 *
 * Copyright (C) 2004 Carlos Pereira
 *
 * Distributed under the terms of the GNU 
 * General Public License: $GAMGI/LICENSE
 *
 */

/**********************
 * external functions *
 **********************/

void gamgi_global_start_help (gamgi_help_class *help_class);

void gamgi_global_start_text (gamgi_text_class *text_class);

void gamgi_global_start_orbital (gamgi_orbital_class *orbital_class);

void gamgi_global_start_bond (gamgi_bond_class *bond_class);

void gamgi_global_start_atom (gamgi_atom_class *atom_class);

void gamgi_global_start_direction (gamgi_direction_class *direction_class);

void gamgi_global_start_plane (gamgi_plane_class *plane_class);

void gamgi_global_start_group (gamgi_group_class *group_class);

void gamgi_global_start_molecule (gamgi_molecule_class *molecule_class);

void gamgi_global_start_cluster (gamgi_cluster_class *cluster_class);

void gamgi_global_start_cell (gamgi_cell_class *cell_class);

void gamgi_global_start_arrow (gamgi_arrow_class *arrow_class);

void gamgi_global_start_shape (gamgi_shape_class *shape_class);

void gamgi_global_start_graph (gamgi_graph_class *graph_class);

void gamgi_global_start_assembly (gamgi_assembly_class *assembly_class);

void gamgi_global_start_light (gamgi_light_class *light_class);

void gamgi_global_start_layer (gamgi_layer_class *layer_class);

void gamgi_global_start_window (gamgi_window_class *window_class);

void gamgi_global_start_gamgi (gamgi_gamgi_class *gamgi_class);

/*************
 * Rationale *
 *************



 *************
 * Rationale *
 *************/
